@@ -48,6 +48,7 @@ def Redondear(expr):#Redondeamos la expresión.
 
 
 def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que es un derivado.
+  print("")
   Tipo = None
   if isinstance(elemento,sympy.core.relational.Equality):#Si el elemento ingresado es una ecuación, entonces la identificamos
     Tipo = "Ecuacion"
@@ -69,18 +70,18 @@ def D(elemento,color = "red"):#Por default se imprime en rojo, para indicar que
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
 
   if Tipo == "Componente":#Si hemos identificado el elemento ingresado como un componente, entonces lo imprimimos en rojo
-    if c_componente[1] == None:
-      mascara = "\\cdots"
-    else:
-      mascara = c_componente[1]
+
 
     #if not isinstance(c_componente[0],str):#isinstance(c_componente[0],sy.core.symbol.Symbol) or isinstance(c_componente[0],sy.core.symbol.Symbol) :
     a = sympy.latex(c_componente[0])
 
     b = " = "
 
-    c = sympy.latex(Redondear(mascara))
-
+    if c_componente[1] == None:
+      c = "\\cdots"
+    else:
+      c = sympy.latex(Redondear(mascara))
+    
     texto = a + b + c
       #texto = texto.replace("text", Estilo)
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
